from enum import Enum

class Category(Enum):
    APP_USAGE = "APP_USAGE"
    APP_STORE_ENGAGEMENT = "APP_STORE_ENGAGEMENT"
    COMMERCE = "COMMERCE"
    FRAMEWORK_USAGE = "FRAMEWORK_USAGE"
    PERFORMANCE = "PERFORMANCE"